unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus, VCLTee.TeEngine, Vcl.ExtCtrls, VCLTee.TeeProcs, VCLTee.Chart,
  VCLTee.Series, VCLTee.TeeTools, VCLTee.GanttCh, Vcl.StdCtrls;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Chart2: TChart;
    Series1: TLineSeries;
    ChartTool1: TCursorTool;
    ChartTool2: TCursorTool;
    Series2: TGanttSeries;
    procedure ChartTool1Change(Sender: TCursorTool; x, y: Integer; const XValue, YValue: Double; Series: TChartSeries;
      ValueIndex: Integer);

    procedure FormShow(Sender: TObject);
    procedure ChartTool2Change(Sender: TCursorTool; x, y: Integer; const XValue,
      YValue: Double; Series: TChartSeries; ValueIndex: Integer);
  private
    { Dclarations prives }
    procedure CursorSynchronize( Source, Dest: TCursorTool );
  public
    { Dclarations publiques }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses DateUtils;

// This procedure synchronizes two cursors.
// "Source" is the original cursor, and "Dest" the cursor
// that is re-positioned.

Procedure TForm1.CursorSynchronize( Source, Dest: TCursorTool );
var tmpEvent: TCursorToolChangeEvent;
begin
  Dest.ParentChart.AutoRepaint:=False; // stop repainting
  Dest.RedrawCursor;   // hide cursor

  tmpEvent:=Dest.OnChange;
  Dest.OnChange:=nil;
  //Dest.YValue := Source.YValue;
  Dest.XValue := Source.XValue;
  Dest.OnChange:=tmpEvent;

  Dest.RedrawCursor;  // draw cursor again
  Dest.ParentChart.AutoRepaint:=True; // enable repainting
end;

Procedure LeftAlignCharts(Const Charts: Array of TCustomChart; aLeft: Integer; aWidth: Integer);

Var i,
    LabelSize : Integer;

Begin
  For i := Low(Charts) to High(Charts) do
  With Charts[i] do
  Begin
    Left := aLeft;
    MarginLeft := 10;
    Width := aWidth;
    LeftAxis.LabelsSize := 100;
  End;
End;

procedure TForm1.ChartTool1Change(Sender: TCursorTool; x,
  y: Integer; const XValue, YValue: Double; Series: TChartSeries;
  ValueIndex: Integer);
var
  MyPoint : TPoint;
begin
  MyPoint := Chart1.ScreenToClient(Mouse.CursorPos);
  if PtInRect(Chart1.ClientRect, MyPoint) then
  begin
    ChartTool1.Style := TCursorToolStyle.cssBoth;
    CursorSynchronize( Sender, ChartTool2 );
  end;
end;

procedure TForm1.ChartTool2Change(Sender: TCursorTool; x, y: Integer;
  const XValue, YValue: Double; Series: TChartSeries; ValueIndex: Integer);
var
  MyPoint : TPoint;
begin
  MyPoint := Chart2.ScreenToClient(Mouse.CursorPos);
  if PtInRect(Chart2.ClientRect, MyPoint) then
  begin
    ChartTool2.Style := TCursorToolStyle.cssBoth;
    CursorSynchronize( Sender, ChartTool1 );
  end;
end;

procedure TForm1.FormShow(Sender: TObject);
var tmpDate: TDateTime;
    i: Integer;
begin
  Series1.Clear;

  Chart1.BottomAxis.Automatic := TRUE;
  Series1.XValues.DateTime := TRUE;

  tmpDate:=Now;
  for i:=0 to 1440 do
  begin
    Series1.AddXY(tmpDate, random*100);
    {Series6.AddXY(tmpDate, random*100);
    Series3.AddXY(tmpDate, random*100);
    Series4.AddXY(tmpDate, random*100);
    Series5.AddXY(tmpDate, random*100);}
    tmpDate:=IncMinute(tmpDate);
  end;

  Series2.Clear;
  tmpDate:=Now;
  for i:=0 to 23 do
  begin
    Series2.AddGanttColor(tmpDate, IncHour(tmpDate), i, '',clRed);
    tmpDate:=IncHour(tmpDate);
  end;

  LeftAlignCharts([Chart1,Chart2],500,Form1.Width);

  ChartTool1.FullRepaint:=False;
  ChartTool2.FullRepaint:=False;
end;

end.
